# clever_client
Serves the Clever Data API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 3.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

### Install Azure artifacts keyring to get access to StrongMind pip packages
`pip install twine keyring artifacts-keyring`

### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install clever_client --extra-index-url https://pkgs.dev.azure.com/strongmind/Strongmind/_packaging/StrongMindPackages/pypi/simple/

```

Then import the package:
```python
import clever_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import clever_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import clever_client
from clever_client.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth
configuration = clever_client.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = clever_client.CoursesApi(clever_client.ApiClient(configuration))
id = 'id_example' # str | 

try:
    api_response = api_instance.get_course(id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CoursesApi->get_course: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.clever.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CoursesApi* | [**get_course**](docs/CoursesApi.md#get_course) | **GET** /courses/{id} | 
*CoursesApi* | [**get_courses**](docs/CoursesApi.md#get_courses) | **GET** /courses | 
*CoursesApi* | [**get_district_for_course**](docs/CoursesApi.md#get_district_for_course) | **GET** /courses/{id}/district | 
*CoursesApi* | [**get_resources_for_course**](docs/CoursesApi.md#get_resources_for_course) | **GET** /courses/{id}/resources | 
*CoursesApi* | [**get_schools_for_course**](docs/CoursesApi.md#get_schools_for_course) | **GET** /courses/{id}/schools | 
*CoursesApi* | [**get_sections_for_course**](docs/CoursesApi.md#get_sections_for_course) | **GET** /courses/{id}/sections | 
*DistrictsApi* | [**get_district**](docs/DistrictsApi.md#get_district) | **GET** /districts/{id} | 
*DistrictsApi* | [**get_districts**](docs/DistrictsApi.md#get_districts) | **GET** /districts | 
*EventsApi* | [**get_event**](docs/EventsApi.md#get_event) | **GET** /events/{id} | 
*EventsApi* | [**get_events**](docs/EventsApi.md#get_events) | **GET** /events | 
*ResourcesApi* | [**get_courses_for_resource**](docs/ResourcesApi.md#get_courses_for_resource) | **GET** /resources/{id}/courses | 
*ResourcesApi* | [**get_resource**](docs/ResourcesApi.md#get_resource) | **GET** /resources/{id} | 
*ResourcesApi* | [**get_resources**](docs/ResourcesApi.md#get_resources) | **GET** /resources | 
*ResourcesApi* | [**get_sections_for_resource**](docs/ResourcesApi.md#get_sections_for_resource) | **GET** /resources/{id}/sections | 
*ResourcesApi* | [**get_users_for_resource**](docs/ResourcesApi.md#get_users_for_resource) | **GET** /resources/{id}/users | 
*SchoolsApi* | [**get_courses_for_school**](docs/SchoolsApi.md#get_courses_for_school) | **GET** /schools/{id}/courses | 
*SchoolsApi* | [**get_district_for_school**](docs/SchoolsApi.md#get_district_for_school) | **GET** /schools/{id}/district | 
*SchoolsApi* | [**get_school**](docs/SchoolsApi.md#get_school) | **GET** /schools/{id} | 
*SchoolsApi* | [**get_schools**](docs/SchoolsApi.md#get_schools) | **GET** /schools | 
*SchoolsApi* | [**get_sections_for_school**](docs/SchoolsApi.md#get_sections_for_school) | **GET** /schools/{id}/sections | 
*SchoolsApi* | [**get_terms_for_school**](docs/SchoolsApi.md#get_terms_for_school) | **GET** /schools/{id}/terms | 
*SchoolsApi* | [**get_users_for_school**](docs/SchoolsApi.md#get_users_for_school) | **GET** /schools/{id}/users | 
*SectionsApi* | [**get_course_for_section**](docs/SectionsApi.md#get_course_for_section) | **GET** /sections/{id}/course | 
*SectionsApi* | [**get_district_for_section**](docs/SectionsApi.md#get_district_for_section) | **GET** /sections/{id}/district | 
*SectionsApi* | [**get_resources_for_section**](docs/SectionsApi.md#get_resources_for_section) | **GET** /sections/{id}/resources | 
*SectionsApi* | [**get_school_for_section**](docs/SectionsApi.md#get_school_for_section) | **GET** /sections/{id}/school | 
*SectionsApi* | [**get_section**](docs/SectionsApi.md#get_section) | **GET** /sections/{id} | 
*SectionsApi* | [**get_sections**](docs/SectionsApi.md#get_sections) | **GET** /sections | 
*SectionsApi* | [**get_term_for_section**](docs/SectionsApi.md#get_term_for_section) | **GET** /sections/{id}/term | 
*SectionsApi* | [**get_users_for_section**](docs/SectionsApi.md#get_users_for_section) | **GET** /sections/{id}/users | 
*TermsApi* | [**get_district_for_term**](docs/TermsApi.md#get_district_for_term) | **GET** /terms/{id}/district | 
*TermsApi* | [**get_schools_for_term**](docs/TermsApi.md#get_schools_for_term) | **GET** /terms/{id}/schools | 
*TermsApi* | [**get_sections_for_term**](docs/TermsApi.md#get_sections_for_term) | **GET** /terms/{id}/sections | 
*TermsApi* | [**get_term**](docs/TermsApi.md#get_term) | **GET** /terms/{id} | 
*TermsApi* | [**get_terms**](docs/TermsApi.md#get_terms) | **GET** /terms | 
*UsersApi* | [**get_contacts_for_user**](docs/UsersApi.md#get_contacts_for_user) | **GET** /users/{id}/mycontacts | 
*UsersApi* | [**get_district_for_user**](docs/UsersApi.md#get_district_for_user) | **GET** /users/{id}/district | 
*UsersApi* | [**get_resources_for_user**](docs/UsersApi.md#get_resources_for_user) | **GET** /users/{id}/resources | 
*UsersApi* | [**get_schools_for_user**](docs/UsersApi.md#get_schools_for_user) | **GET** /users/{id}/schools | 
*UsersApi* | [**get_sections_for_user**](docs/UsersApi.md#get_sections_for_user) | **GET** /users/{id}/sections | 
*UsersApi* | [**get_students_for_user**](docs/UsersApi.md#get_students_for_user) | **GET** /users/{id}/mystudents | 
*UsersApi* | [**get_teachers_for_user**](docs/UsersApi.md#get_teachers_for_user) | **GET** /users/{id}/myteachers | 
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /users/{id} | 
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users) | **GET** /users | 


## Documentation For Models

 - [BadRequest](docs/BadRequest.md)
 - [Contact](docs/Contact.md)
 - [Course](docs/Course.md)
 - [CourseObject](docs/CourseObject.md)
 - [CourseResponse](docs/CourseResponse.md)
 - [CoursesCreated](docs/CoursesCreated.md)
 - [CoursesDeleted](docs/CoursesDeleted.md)
 - [CoursesResponse](docs/CoursesResponse.md)
 - [CoursesUpdated](docs/CoursesUpdated.md)
 - [Credentials](docs/Credentials.md)
 - [District](docs/District.md)
 - [DistrictAdmin](docs/DistrictAdmin.md)
 - [DistrictContact](docs/DistrictContact.md)
 - [DistrictObject](docs/DistrictObject.md)
 - [DistrictResponse](docs/DistrictResponse.md)
 - [DistrictsCreated](docs/DistrictsCreated.md)
 - [DistrictsDeleted](docs/DistrictsDeleted.md)
 - [DistrictsResponse](docs/DistrictsResponse.md)
 - [DistrictsUpdated](docs/DistrictsUpdated.md)
 - [Event](docs/Event.md)
 - [EventResponse](docs/EventResponse.md)
 - [EventResponseWithUri](docs/EventResponseWithUri.md)
 - [EventsResponse](docs/EventsResponse.md)
 - [InternalError](docs/InternalError.md)
 - [Link](docs/Link.md)
 - [Location](docs/Location.md)
 - [Name](docs/Name.md)
 - [NotFound](docs/NotFound.md)
 - [Principal](docs/Principal.md)
 - [Resource](docs/Resource.md)
 - [ResourceObject](docs/ResourceObject.md)
 - [ResourceResponse](docs/ResourceResponse.md)
 - [ResourcesCreated](docs/ResourcesCreated.md)
 - [ResourcesDeleted](docs/ResourcesDeleted.md)
 - [ResourcesResponse](docs/ResourcesResponse.md)
 - [ResourcesUpdated](docs/ResourcesUpdated.md)
 - [Roles](docs/Roles.md)
 - [School](docs/School.md)
 - [SchoolEnrollment](docs/SchoolEnrollment.md)
 - [SchoolObject](docs/SchoolObject.md)
 - [SchoolResponse](docs/SchoolResponse.md)
 - [SchoolsCreated](docs/SchoolsCreated.md)
 - [SchoolsDeleted](docs/SchoolsDeleted.md)
 - [SchoolsResponse](docs/SchoolsResponse.md)
 - [SchoolsUpdated](docs/SchoolsUpdated.md)
 - [Section](docs/Section.md)
 - [SectionObject](docs/SectionObject.md)
 - [SectionResponse](docs/SectionResponse.md)
 - [SectionsCreated](docs/SectionsCreated.md)
 - [SectionsDeleted](docs/SectionsDeleted.md)
 - [SectionsResponse](docs/SectionsResponse.md)
 - [SectionsUpdated](docs/SectionsUpdated.md)
 - [Staff](docs/Staff.md)
 - [Student](docs/Student.md)
 - [StudentRelationship](docs/StudentRelationship.md)
 - [Teacher](docs/Teacher.md)
 - [Term](docs/Term.md)
 - [TermObject](docs/TermObject.md)
 - [TermResponse](docs/TermResponse.md)
 - [TermsCreated](docs/TermsCreated.md)
 - [TermsDeleted](docs/TermsDeleted.md)
 - [TermsResponse](docs/TermsResponse.md)
 - [TermsUpdated](docs/TermsUpdated.md)
 - [User](docs/User.md)
 - [UserObject](docs/UserObject.md)
 - [UserResponse](docs/UserResponse.md)
 - [UsersCreated](docs/UsersCreated.md)
 - [UsersDeleted](docs/UsersDeleted.md)
 - [UsersResponse](docs/UsersResponse.md)
 - [UsersUpdated](docs/UsersUpdated.md)


## Documentation For Authorization


## oauth

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://clever.com/oauth/authorize
- **Scopes**: N/A


## Author

platform@strongmind.com

